@@ -1,6 +1,6 @@
-/**
- *  Copyright (C) 2017 Ryszard Wiśniewski <brut.alll@gmail.com>
- *  Copyright (C) 2017 Connor Tumbleson <connor.tumbleson@gmail.com>
+/*
+ *  Copyright (C) 2010 Ryszard Wiśniewski <brut.alll@gmail.com>
+ *  Copyright (C) 2010 Connor Tumbleson <connor.tumbleson@gmail.com>
  *
  *  Licensed under the Apache License, Version 2.0 (the "License");
  *  you may not use this file except in compliance with the License.
@@ -22,6 +22,8 @@ import brut.androlib.err.InFileNotFoundException;
 import brut.androlib.err.OutDirExistsException;
 import brut.common.BrutException;
 import brut.directory.DirectoryException;
+import brut.util.AaptManager;
+import brut.util.OSDetection;
 import org.apache.commons.cli.*;
 
 import java.io.File;
@@ -35,6 +37,9 @@ import java.util.logging.*;
 public class Main {
     public static void main(String[] args) throws IOException, InterruptedException, BrutException {
 
+        // headless
+        System.setProperty("java.awt.headless", "true");
+
         // set verbosity default
         Verbosity verbosity = Verbosity.NORMAL;
 
@@ -47,9 +52,14 @@ public class Main {
 
         try {
             commandLine = parser.parse(allOptions, args, false);
+
+            if (! OSDetection.is64Bit()) {
+                System.err.println("32 bit support is deprecated. Apktool will not support 32bit on v2.6.0.");
+            }
         } catch (ParseException ex) {
             System.err.println(ex.getMessage());
             usage();
+            System.exit(1);
             return;
         }
 
@@ -63,7 +73,7 @@ public class Main {
 
         // check for advance mode
         if (commandLine.hasOption("advance") || commandLine.hasOption("advanced")) {
-            setAdvanceMode(true);
+            setAdvanceMode();
         }
 
         boolean cmdFound = false;
@@ -80,6 +90,9 @@ public class Main {
             } else if (opt.equalsIgnoreCase("empty-framework-dir")) {
                 cmdEmptyFrameworkDirectory(commandLine);
                 cmdFound = true;
+            } else if (opt.equalsIgnoreCase("list-frameworks")) {
+                cmdListFrameworks(commandLine);
+                cmdFound = true;
             } else if (opt.equalsIgnoreCase("publicize-resources")) {
                 cmdPublicizeResources(commandLine);
                 cmdFound = true;
@@ -108,6 +121,9 @@ public class Main {
         if (cli.hasOption("s") || cli.hasOption("no-src")) {
             decoder.setDecodeSources(ApkDecoder.DECODE_SOURCES_NONE);
         }
+        if (cli.hasOption("only-main-classes")) {
+            decoder.setDecodeSources(ApkDecoder.DECODE_SOURCES_SMALI_ONLY_MAIN_CLASSES);
+        }
         if (cli.hasOption("d") || cli.hasOption("debug")) {
             System.err.println("SmaliDebugging has been removed in 2.1.0 onward. Please see: https://github.com/iBotPeaches/Apktool/issues/1061");
             System.exit(1);
@@ -202,7 +218,6 @@ public class Main {
             apkOptions.forceBuildAll = true;
         }
         if (cli.hasOption("d") || cli.hasOption("debug")) {
-            System.out.println("SmaliDebugging has been removed in 2.1.0 onward. Please see: https://github.com/iBotPeaches/Apktool/issues/1061");
             apkOptions.debugMode = true;
         }
         if (cli.hasOption("v") || cli.hasOption("verbose")) {
@@ -212,11 +227,24 @@ public class Main {
             apkOptions.aaptPath = cli.getOptionValue("a");
         }
         if (cli.hasOption("c") || cli.hasOption("copy-original")) {
+            System.err.println("-c/--copy-original has been deprecated. Removal planned for v2.6.0 (#2129)");
             apkOptions.copyOriginalFiles = true;
         }
         if (cli.hasOption("p") || cli.hasOption("frame-path")) {
             apkOptions.frameworkFolderLocation = cli.getOptionValue("p");
         }
+        if (cli.hasOption("nc") || cli.hasOption("no-crunch")) {
+            apkOptions.noCrunch = true;
+        }
+
+        // Temporary flag to enable the use of aapt2. This will tranform in time to a use-aapt1 flag, which will be
+        // legacy and eventually removed.
+        if (cli.hasOption("use-aapt2")) {
+            apkOptions.useAapt2 = true;
+        }
+        if (cli.hasOption("api") || cli.hasOption("api-level")) {
+            apkOptions.forceApi = Integer.parseInt(cli.getOptionValue("api"));
+        }
         if (cli.hasOption("o") || cli.hasOption("output")) {
             outFile = new File(cli.getOptionValue("o"));
         } else {
@@ -224,7 +252,15 @@ public class Main {
         }
 
         // try and build apk
-        new Androlib(apkOptions).build(new File(appDirName), outFile);
+        try {
+            if (cli.hasOption("a") || cli.hasOption("aapt")) {
+                apkOptions.aaptVersion = AaptManager.getAaptVersion(cli.getOptionValue("a"));
+            }
+            new Androlib(apkOptions).build(new File(appDirName), outFile);
+        } catch (BrutException ex) {
+            System.err.println(ex.getMessage());
+            System.exit(1);
+        }
     }
 
     private static void cmdInstallFramework(CommandLine cli) throws AndrolibException {
@@ -241,6 +277,15 @@ public class Main {
         new Androlib(apkOptions).installFramework(new File(apkName));
     }
 
+    private static void cmdListFrameworks(CommandLine cli) throws AndrolibException {
+        ApkOptions apkOptions = new ApkOptions();
+        if (cli.hasOption("p") || cli.hasOption("frame-path")) {
+            apkOptions.frameworkFolderLocation = cli.getOptionValue("p");
+        }
+
+        new Androlib(apkOptions).listFrameworks();
+    }
+
     private static void cmdPublicizeResources(CommandLine cli) throws AndrolibException {
         int paraCount = cli.getArgList().size();
         String apkName = cli.getArgList().get(paraCount - 1);
@@ -284,6 +329,11 @@ public class Main {
                 .desc("Do not decode sources.")
                 .build();
 
+        Option onlyMainClassesOption = Option.builder()
+                .longOpt("only-main-classes")
+                .desc("Only disassemble the main dex classes (classes[0-9]*.dex) in the root.")
+                .build();
+
         Option noResOption = Option.builder("r")
                 .longOpt("no-res")
                 .desc("Do not decode resources.")
@@ -372,11 +422,21 @@ public class Main {
                 .desc("Loads aapt from specified location.")
                 .build();
 
+        Option aapt2Option = Option.builder()
+                .longOpt("use-aapt2")
+                .desc("Upgrades apktool to use experimental aapt2 binary.")
+                .build();
+
         Option originalOption = Option.builder("c")
                 .longOpt("copy-original")
                 .desc("Copies original AndroidManifest.xml and META-INF. See project page for more info.")
                 .build();
 
+        Option noCrunchOption = Option.builder("nc")
+                .longOpt("no-crunch")
+                .desc("Disable crunching of resource files during the build step.")
+                .build();
+
         Option tagOption = Option.builder("t")
                 .longOpt("tag")
                 .desc("Tag frameworks using <tag>.")
@@ -411,13 +471,17 @@ public class Main {
             DecodeOptions.addOption(noDbgOption);
             DecodeOptions.addOption(keepResOption);
             DecodeOptions.addOption(analysisOption);
+            DecodeOptions.addOption(onlyMainClassesOption);
             DecodeOptions.addOption(apiLevelOption);
             DecodeOptions.addOption(noAssetOption);
             DecodeOptions.addOption(forceManOption);
 
+            BuildOptions.addOption(apiLevelOption);
             BuildOptions.addOption(debugBuiOption);
             BuildOptions.addOption(aaptOption);
             BuildOptions.addOption(originalOption);
+            BuildOptions.addOption(aapt2Option);
+            BuildOptions.addOption(noCrunchOption);
         }
 
         // add global options
@@ -445,6 +509,9 @@ public class Main {
         emptyFrameworkOptions.addOption(forceDecOption);
         emptyFrameworkOptions.addOption(frameIfDirOption);
 
+        // add list framework options
+        listFrameworkOptions.addOption(frameIfDirOption);
+
         // add all, loop existing cats then manually add advance
         for (Object op : normalOptions.getOptions()) {
             allOptions.addOption((Option)op);
@@ -470,6 +537,9 @@ public class Main {
         allOptions.addOption(originalOption);
         allOptions.addOption(verboseOption);
         allOptions.addOption(quietOption);
+        allOptions.addOption(aapt2Option);
+        allOptions.addOption(noCrunchOption);
+        allOptions.addOption(onlyMainClassesOption);
     }
 
     private static String verbosityHelp() {
@@ -490,10 +560,10 @@ public class Main {
                 "Apktool v" + Androlib.getVersion() + " - a tool for reengineering Android apk files\n" +
                         "with smali v" + ApktoolProperties.get("smaliVersion") +
                         " and baksmali v" + ApktoolProperties.get("baksmaliVersion") + "\n" +
-                        "Copyright 2014 Ryszard Wiśniewski <brut.alll@gmail.com>\n" +
-                        "Updated by Connor Tumbleson <connor.tumbleson@gmail.com>" );
+                        "Copyright 2010 Ryszard Wiśniewski <brut.alll@gmail.com>\n" +
+                        "Copyright 2010 Connor Tumbleson <connor.tumbleson@gmail.com>" );
         if (isAdvanceMode()) {
-            System.out.println("Apache License 2.0 (http://www.apache.org/licenses/LICENSE-2.0)\n");
+            System.out.println("Apache License 2.0 (https://www.apache.org/licenses/LICENSE-2.0)\n");
         }else {
             System.out.println("");
         }
@@ -506,6 +576,7 @@ public class Main {
         if (isAdvanceMode()) {
             formatter.printHelp("apktool " + verbosityHelp() + "publicize-resources <file_path>", emptyOptions);
             formatter.printHelp("apktool " + verbosityHelp() + "empty-framework-dir [options]", emptyFrameworkOptions);
+            formatter.printHelp("apktool " + verbosityHelp() + "list-frameworks [options]", listFrameworkOptions);
             System.out.println("");
         } else {
             System.out.println("");
@@ -513,7 +584,7 @@ public class Main {
 
         // print out more information
         System.out.println(
-                "For additional info, see: http://ibotpeaches.github.io/Apktool/ \n"
+                "For additional info, see: https://ibotpeaches.github.io/Apktool/ \n"
                         + "For smali/baksmali info, see: https://github.com/JesusFreke/smali");
     }
 
@@ -579,8 +650,8 @@ public class Main {
         return advanceMode;
     }
 
-    private static void setAdvanceMode(boolean advanceMode) {
-        Main.advanceMode = advanceMode;
+    private static void setAdvanceMode() {
+        Main.advanceMode = true;
     }
 
     private enum Verbosity {
@@ -596,6 +667,7 @@ public class Main {
     private final static Options allOptions;
     private final static Options emptyOptions;
     private final static Options emptyFrameworkOptions;
+    private final static Options listFrameworkOptions;
 
     static {
         //normal and advance usage output
@@ -606,5 +678,6 @@ public class Main {
         allOptions = new Options();
         emptyOptions = new Options();
         emptyFrameworkOptions = new Options();
+        listFrameworkOptions = new Options();
     }
 }
