@@ -1,6 +1,6 @@
-/**
- *  Copyright (C) 2017 Ryszard Wiśniewski <brut.alll@gmail.com>
- *  Copyright (C) 2017 Connor Tumbleson <connor.tumbleson@gmail.com>
+/*
+ *  Copyright (C) 2010 Ryszard Wiśniewski <brut.alll@gmail.com>
+ *  Copyright (C) 2010 Connor Tumbleson <connor.tumbleson@gmail.com>
  *
  *  Licensed under the Apache License, Version 2.0 (the "License");
  *  you may not use this file except in compliance with the License.
@@ -18,7 +18,7 @@ package brut.androlib;
 
 import brut.androlib.err.InFileNotFoundException;
 import brut.androlib.err.OutDirExistsException;
-import brut.androlib.err.UndefinedResObject;
+import brut.androlib.err.UndefinedResObjectException;
 import brut.androlib.meta.MetaInfo;
 import brut.androlib.meta.PackageInfo;
 import brut.androlib.meta.UsesFramework;
@@ -144,6 +144,7 @@ public class ApkDecoder {
                         mAndrolib.decodeSourcesRaw(mApkFile, outDir, "classes.dex");
                         break;
                     case DECODE_SOURCES_SMALI:
+                    case DECODE_SOURCES_SMALI_ONLY_MAIN_CLASSES:
                         mAndrolib.decodeSourcesSmali(mApkFile, outDir, "classes.dex", mBakDeb, mApi);
                         break;
                 }
@@ -162,6 +163,13 @@ public class ApkDecoder {
                                 case DECODE_SOURCES_SMALI:
                                     mAndrolib.decodeSourcesSmali(mApkFile, outDir, file, mBakDeb, mApi);
                                     break;
+                                case DECODE_SOURCES_SMALI_ONLY_MAIN_CLASSES:
+                                    if (file.startsWith("classes") && file.endsWith(".dex")) {
+                                        mAndrolib.decodeSourcesSmali(mApkFile, outDir, file, mBakDeb, mApi);
+                                    } else {
+                                        mAndrolib.decodeSourcesRaw(mApkFile, outDir, file);
+                                    }
+                                    break;
                             }
                         }
                     }
@@ -184,7 +192,7 @@ public class ApkDecoder {
     }
 
     public void setDecodeSources(short mode) throws AndrolibException {
-        if (mode != DECODE_SOURCES_NONE && mode != DECODE_SOURCES_SMALI) {
+        if (mode != DECODE_SOURCES_NONE && mode != DECODE_SOURCES_SMALI && mode != DECODE_SOURCES_SMALI_ONLY_MAIN_CLASSES) {
             throw new AndrolibException("Invalid decode sources mode: " + mode);
         }
         mDecodeSources = mode;
@@ -316,6 +324,7 @@ public class ApkDecoder {
 
     public final static short DECODE_SOURCES_NONE = 0x0000;
     public final static short DECODE_SOURCES_SMALI = 0x0001;
+    public final static short DECODE_SOURCES_SMALI_ONLY_MAIN_CLASSES = 0x0010;
 
     public final static short DECODE_RESOURCES_NONE = 0x0100;
     public final static short DECODE_RESOURCES_FULL = 0x0101;
@@ -345,6 +354,7 @@ public class ApkDecoder {
             putPackageInfo(meta);
             putVersionInfo(meta);
             putSharedLibraryInfo(meta);
+            putSparseResourcesInfo(meta);
         }
         putUnknownInfo(meta);
         putFileCompressionInfo(meta);
@@ -376,6 +386,25 @@ public class ApkDecoder {
     private void putSdkInfo(MetaInfo meta) throws AndrolibException {
         Map<String, String> info = getResTable().getSdkInfo();
         if (info.size() > 0) {
+            String refValue;
+            if (info.get("minSdkVersion") != null) {
+                refValue = ResXmlPatcher.pullValueFromIntegers(mOutDir, info.get("minSdkVersion"));
+                if (refValue != null) {
+                    info.put("minSdkVersion", refValue);
+                }
+            }
+            if (info.get("targetSdkVersion") != null) {
+                refValue = ResXmlPatcher.pullValueFromIntegers(mOutDir, info.get("targetSdkVersion"));
+                if (refValue != null) {
+                    info.put("targetSdkVersion", refValue);
+                }
+            }
+            if (info.get("maxSdkVersion") != null) {
+                refValue = ResXmlPatcher.pullValueFromIntegers(mOutDir, info.get("maxSdkVersion"));
+                if (refValue != null) {
+                    info.put("maxSdkVersion", refValue);
+                }
+            }
             meta.sdkInfo = info;
         }
     }
@@ -387,7 +416,7 @@ public class ApkDecoder {
         int id = getResTable().getPackageId();
         try {
             id = getResTable().getPackage(renamed).getId();
-        } catch (UndefinedResObject ignored) {}
+        } catch (UndefinedResObjectException ignored) {}
 
         if (Strings.isNullOrEmpty(original)) {
             return;
@@ -421,6 +450,10 @@ public class ApkDecoder {
         }
     }
 
+    private void putSparseResourcesInfo(MetaInfo meta) throws AndrolibException {
+        meta.sparseResources = mResTable.getSparseResources();
+    }
+
     private void putSharedLibraryInfo(MetaInfo meta) throws AndrolibException {
         meta.sharedLibrary = mResTable.getSharedLibrary();
     }
