@@ -1,6 +1,6 @@
-/**
- *  Copyright (C) 2017 Ryszard Wiśniewski <brut.alll@gmail.com>
- *  Copyright (C) 2017 Connor Tumbleson <connor.tumbleson@gmail.com>
+/*
+ *  Copyright (C) 2010 Ryszard Wiśniewski <brut.alll@gmail.com>
+ *  Copyright (C) 2010 Connor Tumbleson <connor.tumbleson@gmail.com>
  *
  *  Licensed under the Apache License, Version 2.0 (the "License");
  *  you may not use this file except in compliance with the License.
@@ -22,19 +22,6 @@ import brut.androlib.AndrolibException;
  * @author Ryszard Wiśniewski <brut.alll@gmail.com>
  */
 public class InFileNotFoundException extends AndrolibException {
-
-	public InFileNotFoundException(Throwable cause) {
-		super(cause);
-	}
-
-	public InFileNotFoundException(String message, Throwable cause) {
-		super(message, cause);
-	}
-
-	public InFileNotFoundException(String message) {
-		super(message);
-	}
-
 	public InFileNotFoundException() {
 	}
 }
