@@ -1,6 +1,6 @@
-/**
- *  Copyright (C) 2017 Ryszard Wiśniewski <brut.alll@gmail.com>
- *  Copyright (C) 2017 Connor Tumbleson <connor.tumbleson@gmail.com>
+/*
+ *  Copyright (C) 2010 Ryszard Wiśniewski <brut.alll@gmail.com>
+ *  Copyright (C) 2010 Connor Tumbleson <connor.tumbleson@gmail.com>
  *
  *  Licensed under the Apache License, Version 2.0 (the "License");
  *  you may not use this file except in compliance with the License.
@@ -35,6 +35,7 @@ public class MetaInfo {
     public VersionInfo versionInfo;
     public boolean compressionType;
     public boolean sharedLibrary;
+    public boolean sparseResources;
     public Map<String, String> unknownFiles;
     public Collection<String> doNotCompress;
 
@@ -60,7 +61,7 @@ public class MetaInfo {
                 FileOutputStream fos = new FileOutputStream(file);
                 OutputStreamWriter outputStreamWriter = new OutputStreamWriter(fos, StandardCharsets.UTF_8);
                 Writer writer = new BufferedWriter(outputStreamWriter)
-        ){
+        ) {
             save(writer);
         }
     }
@@ -68,12 +69,4 @@ public class MetaInfo {
     public static MetaInfo load(InputStream is) {
         return getYaml().loadAs(is, MetaInfo.class);
     }
-
-    public static MetaInfo load(File file) throws IOException {
-        try (
-                InputStream fis = new FileInputStream(file)
-        ){
-            return load(fis);
-        }
-    }
 }
