@@ -1,6 +1,6 @@
-/**
- *  Copyright (C) 2017 Ryszard Wiśniewski <brut.alll@gmail.com>
- *  Copyright (C) 2017 Connor Tumbleson <connor.tumbleson@gmail.com>
+/*
+ *  Copyright (C) 2010 Ryszard Wiśniewski <brut.alll@gmail.com>
+ *  Copyright (C) 2010 Connor Tumbleson <connor.tumbleson@gmail.com>
  *
  *  Licensed under the Apache License, Version 2.0 (the "License");
  *  you may not use this file except in compliance with the License.
@@ -17,6 +17,8 @@
 package brut.androlib.mod;
 
 import java.io.*;
+import java.nio.charset.StandardCharsets;
+
 import org.antlr.runtime.*;
 import org.antlr.runtime.tree.CommonTree;
 import org.antlr.runtime.tree.CommonTreeNodeStream;
@@ -29,14 +31,14 @@ import org.jf.smali.*;
  */
 public class SmaliMod {
 
-    public static boolean assembleSmaliFile(String smali, DexBuilder dexBuilder, boolean verboseErrors,
+    public static boolean assembleSmaliFile(String smali, DexBuilder dexBuilder, int apiLevel, boolean verboseErrors,
                                             boolean printTokens, File smaliFile) throws IOException, RuntimeException, RecognitionException {
 
         InputStream is = new ByteArrayInputStream(smali.getBytes());
-        return assembleSmaliFile(is, dexBuilder, verboseErrors, printTokens, smaliFile);
+        return assembleSmaliFile(is, dexBuilder, apiLevel, verboseErrors, printTokens, smaliFile);
     }
 
-    public static boolean assembleSmaliFile(InputStream is,DexBuilder dexBuilder, boolean verboseErrors,
+    public static boolean assembleSmaliFile(InputStream is,DexBuilder dexBuilder, int apiLevel, boolean verboseErrors,
                                             boolean printTokens, File smaliFile) throws IOException, RecognitionException {
 
         // copy our filestream into a tmp file, so we don't overwrite
@@ -47,21 +49,21 @@ public class SmaliMod {
         IOUtils.copy(is, os);
         os.close();
 
-        return assembleSmaliFile(tmp,dexBuilder, verboseErrors, printTokens);
+        return assembleSmaliFile(tmp,dexBuilder, apiLevel, verboseErrors, printTokens);
     }
 
-    public static boolean assembleSmaliFile(File smaliFile,DexBuilder dexBuilder, boolean verboseErrors,
+    public static boolean assembleSmaliFile(File smaliFile,DexBuilder dexBuilder, int apiLevel, boolean verboseErrors,
                                             boolean printTokens) throws IOException, RecognitionException {
 
         CommonTokenStream tokens;
-        LexerErrorInterface lexer;
+        smaliFlexLexer lexer;
 
         InputStream is = new FileInputStream(smaliFile);
-        InputStreamReader reader = new InputStreamReader(is, "UTF-8");
+        InputStreamReader reader = new InputStreamReader(is, StandardCharsets.UTF_8);
 
-        lexer = new smaliFlexLexer(reader);
-        ((smaliFlexLexer)lexer).setSourceFile(smaliFile);
-        tokens = new CommonTokenStream((TokenSource) lexer);
+        lexer = new smaliFlexLexer(reader, apiLevel);
+        (lexer).setSourceFile(smaliFile);
+        tokens = new CommonTokenStream(lexer);
 
         if (printTokens) {
             tokens.getTokens();
@@ -77,6 +79,7 @@ public class SmaliMod {
         }
 
         smaliParser parser = new smaliParser(tokens);
+        parser.setApiLevel(apiLevel);
         parser.setVerboseErrors(verboseErrors);
 
         smaliParser.smali_file_return result = parser.smali_file();
@@ -87,13 +90,13 @@ public class SmaliMod {
             return false;
         }
 
-        CommonTree t = (CommonTree) result.getTree();
+        CommonTree t = result.getTree();
 
         CommonTreeNodeStream treeStream = new CommonTreeNodeStream(t);
         treeStream.setTokenStream(tokens);
 
         smaliTreeWalker dexGen = new smaliTreeWalker(treeStream);
-
+        dexGen.setApiLevel(apiLevel);
         dexGen.setVerboseErrors(verboseErrors);
         dexGen.setDexBuilder(dexBuilder);
         dexGen.smali_file();
