@@ -1,6 +1,6 @@
-/**
- *  Copyright (C) 2017 Ryszard Wiśniewski <brut.alll@gmail.com>
- *  Copyright (C) 2017 Connor Tumbleson <connor.tumbleson@gmail.com>
+/*
+ *  Copyright (C) 2010 Ryszard Wiśniewski <brut.alll@gmail.com>
+ *  Copyright (C) 2010 Connor Tumbleson <connor.tumbleson@gmail.com>
  *
  *  Licensed under the Apache License, Version 2.0 (the "License");
  *  you may not use this file except in compliance with the License.
@@ -535,6 +535,14 @@ public class ResConfigFlags {
     public final static byte SDK_NOUGAT = 24;
     public final static byte SDK_NOUGAT_MR1 = 25;
     public final static byte SDK_OREO = 26;
+    public final static byte SDK_OREO_MR1 = 27;
+    public final static byte SDK_P = 28;
+    public final static byte SDK_Q = 29;
+    public final static byte SDK_R = 30;
+
+    // AOSP has this as 10,000 for dev purposes.
+    // platform_frameworks_base/commit/c7a1109a1fe0771d4c9b572dcf178e2779fc4f2d
+    public final static int SDK_S = 10000;
 
     public final static byte ORIENTATION_ANY = 0;
     public final static byte ORIENTATION_PORT = 1;
