@@ -1,6 +1,6 @@
-/**
- *  Copyright (C) 2017 Ryszard Wiśniewski <brut.alll@gmail.com>
- *  Copyright (C) 2017 Connor Tumbleson <connor.tumbleson@gmail.com>
+/*
+ *  Copyright (C) 2010 Ryszard Wiśniewski <brut.alll@gmail.com>
+ *  Copyright (C) 2010 Connor Tumbleson <connor.tumbleson@gmail.com>
  *
  *  Licensed under the Apache License, Version 2.0 (the "License");
  *  you may not use this file except in compliance with the License.
@@ -155,6 +155,9 @@ public class ResFlagsAttr extends ResAttr {
 
         public String getValue() throws AndrolibException {
             if (value == null) {
+                if (ref.referentIsNull()) {
+                    return "@null";
+                }
                 value = ref.getReferent().getName();
             }
             return value;
