@@ -1,6 +1,6 @@
-/**
- *  Copyright (C) 2017 Ryszard Wiśniewski <brut.alll@gmail.com>
- *  Copyright (C) 2017 Connor Tumbleson <connor.tumbleson@gmail.com>
+/*
+ *  Copyright (C) 2010 Ryszard Wiśniewski <brut.alll@gmail.com>
+ *  Copyright (C) 2010 Connor Tumbleson <connor.tumbleson@gmail.com>
  *
  *  Licensed under the Apache License, Version 2.0 (the "License");
  *  you may not use this file except in compliance with the License.
@@ -20,7 +20,7 @@ package brut.androlib.res.data.value;
  * @author Matt Mastracci <matthew@mastracci.com>
  */
 public class ResIntBasedValue extends ResValue {
-    private int mRawIntValue;
+    private final int mRawIntValue;
 
     protected ResIntBasedValue(int rawIntValue) {
         mRawIntValue = rawIntValue;
