@@ -1,6 +1,6 @@
-/**
- *  Copyright (C) 2017 Ryszard Wiśniewski <brut.alll@gmail.com>
- *  Copyright (C) 2017 Connor Tumbleson <connor.tumbleson@gmail.com>
+/*
+ *  Copyright (C) 2010 Ryszard Wiśniewski <brut.alll@gmail.com>
+ *  Copyright (C) 2010 Connor Tumbleson <connor.tumbleson@gmail.com>
  *
  *  Licensed under the Apache License, Version 2.0 (the "License");
  *  you may not use this file except in compliance with the License.
@@ -83,6 +83,13 @@ public abstract class ResScalarValue extends ResIntBasedValue implements
             }
         }
 
+        // Android does not allow values (false) for ids.xml anymore
+        // https://issuetracker.google.com/issues/80475496
+        // But it decodes as a ResBoolean, which makes no sense. So force it to empty
+        if (type.equalsIgnoreCase("id") && !body.isEmpty()) {
+            body = "";
+        }
+
         // check for using attrib as node or item
         String tagName = item ? "item" : type;
 
