@@ -1,6 +1,6 @@
-/**
- *  Copyright (C) 2017 Ryszard Wiśniewski <brut.alll@gmail.com>
- *  Copyright (C) 2017 Connor Tumbleson <connor.tumbleson@gmail.com>
+/*
+ *  Copyright (C) 2010 Ryszard Wiśniewski <brut.alll@gmail.com>
+ *  Copyright (C) 2010 Connor Tumbleson <connor.tumbleson@gmail.com>
  *
  *  Licensed under the Apache License, Version 2.0 (the "License");
  *  you may not use this file except in compliance with the License.
@@ -19,6 +19,7 @@ package brut.androlib.res.decoder;
 import android.content.res.XmlResourceParser;
 import android.util.TypedValue;
 import brut.androlib.AndrolibException;
+import brut.androlib.res.data.ResID;
 import brut.androlib.res.xml.ResXmlEncoders;
 import brut.util.ExtDataInput;
 import com.google.common.io.LittleEndianDataInputStream;
@@ -288,16 +289,15 @@ public class AXmlResourceParser implements XmlResourceParser {
             return "";
         }
 
-        // hacky: if the attribute names are proguarded, then so are the namespace
-        // I don't know where these are located yet in the file, but it is always
-        // this.android_ns in testing, so we will default to that for now.
-        // @todo figure out where proguarded namespaces are stored.
+        // Minifiers like removing the namespace, so we will default to default namespace
+        // unless the pkgId of the resource is private. We will grab the non-standard one.
         String value = m_strings.getString(namespace);
 
         if (value.length() == 0) {
-            int offsetName = getAttributeOffset(index);
-            int name = m_attributes[offsetName + ATTRIBUTE_IX_NAME];
-            if (m_strings.getString(name).length() == 0) {
+            ResID resourceId = new ResID(getAttributeNameResource(index));
+            if (resourceId.package_ == PRIVATE_PKG_ID) {
+                value = getNonDefaultNamespaceUri(offset);
+            } else {
                 value = android_ns;
             }
         }
@@ -305,6 +305,21 @@ public class AXmlResourceParser implements XmlResourceParser {
         return value;
     }
 
+    private String getNonDefaultNamespaceUri(int offset) {
+        String prefix = m_strings.getString(m_namespaces.getPrefix(offset));
+        if (prefix != null) {
+            return  m_strings.getString(m_namespaces.getUri(offset));
+        }
+
+        // If we are here. There is some clever obfuscation going on. Our reference points to the namespace are gone.
+        // Normally we could take the index * attributeCount to get an offset.
+        // That would point to the URI in the StringBlock table, but that is empty.
+        // We have the namespaces that can't be touched in the opening tag.
+        // Though no known way to correlate them at this time.
+        // So return the res-auto namespace.
+        return "http://schemas.android.com/apk/res-auto";
+    }
+
     @Override
     public String getAttributePrefix(int index) {
         int offset = getAttributeOffset(index);
@@ -328,16 +343,15 @@ public class AXmlResourceParser implements XmlResourceParser {
 
         // some attributes will return "", we must rely on the resource_id and refer to the frameworks
         // to match the resource id to the name. ex: 0x101021C = versionName
-        if (value.length() != 0) {
-            return value;
-        } else {
+        if (value.length() == 0 || android_ns.equals(getAttributeNamespace(index))) {
             try {
-                value = mAttrDecoder.decodeManifestAttr(getAttributeNameResource(index));
-            } catch (AndrolibException e) {
-                value = "";
-            }
-            return value;
+                int resourceId = getAttributeNameResource(index);
+                if (resourceId != 0) {
+                    value = mAttrDecoder.decodeManifestAttr(getAttributeNameResource(index));
+                }
+            } catch (AndrolibException | NullPointerException e) { }
         }
+        return value;
     }
 
     @Override
@@ -841,7 +855,7 @@ public class AXmlResourceParser implements XmlResourceParser {
     private final void doNext() throws IOException {
         // Delayed initialization.
         if (m_strings == null) {
-            m_reader.skipCheckInt(CHUNK_AXML_FILE);
+            m_reader.skipCheckInt(CHUNK_AXML_FILE, CHUNK_AXML_FILE_BROKEN);
 
 			/*
 			 * chunkSize
@@ -975,7 +989,7 @@ public class AXmlResourceParser implements XmlResourceParser {
     private StringBlock m_strings;
     private int[] m_resourceIDs;
     private NamespaceStack m_namespaces = new NamespaceStack();
-    private String android_ns = "http://schemas.android.com/apk/res/android";
+    private final String android_ns = "http://schemas.android.com/apk/res/android";
     private boolean m_decreaseDepth;
     private int m_event;
     private int m_lineNumber;
@@ -993,10 +1007,12 @@ public class AXmlResourceParser implements XmlResourceParser {
             ATTRIBUTE_IX_VALUE_TYPE = 3, ATTRIBUTE_IX_VALUE_DATA = 4,
             ATTRIBUTE_LENGTH = 5;
 
-    private static final int CHUNK_AXML_FILE = 0x00080003,
+    private static final int CHUNK_AXML_FILE = 0x00080003, CHUNK_AXML_FILE_BROKEN = 0x00080001,
             CHUNK_RESOURCEIDS = 0x00080180, CHUNK_XML_FIRST = 0x00100100,
             CHUNK_XML_START_NAMESPACE = 0x00100100,
             CHUNK_XML_END_NAMESPACE = 0x00100101,
             CHUNK_XML_START_TAG = 0x00100102, CHUNK_XML_END_TAG = 0x00100103,
             CHUNK_XML_TEXT = 0x00100104, CHUNK_XML_LAST = 0x00100104;
+
+    private static final int PRIVATE_PKG_ID = 0x7F;
 }
