@@ -1,6 +1,6 @@
-/**
- *  Copyright (C) 2017 Ryszard Wiśniewski <brut.alll@gmail.com>
- *  Copyright (C) 2017 Connor Tumbleson <connor.tumbleson@gmail.com>
+/*
+ *  Copyright (C) 2010 Ryszard Wiśniewski <brut.alll@gmail.com>
+ *  Copyright (C) 2010 Connor Tumbleson <connor.tumbleson@gmail.com>
  *
  *  Licensed under the Apache License, Version 2.0 (the "License");
  *  you may not use this file except in compliance with the License.
@@ -47,6 +47,10 @@ public interface Directory {
     public void copyToDir(File out, String fileName)
         throws DirectoryException;
 
+    public long getSize(String fileName)
+            throws DirectoryException;
+    public long getCompressedSize(String fileName)
+            throws DirectoryException;
     public int getCompressionLevel(String fileName)
             throws DirectoryException;
 
