@@ -1,6 +1,6 @@
-/**
- *  Copyright (C) 2017 Ryszard Wiśniewski <brut.alll@gmail.com>
- *  Copyright (C) 2017 Connor Tumbleson <connor.tumbleson@gmail.com>
+/*
+ *  Copyright (C) 2010 Ryszard Wiśniewski <brut.alll@gmail.com>
+ *  Copyright (C) 2010 Connor Tumbleson <connor.tumbleson@gmail.com>
  *
  *  Licensed under the Apache License, Version 2.0 (the "License");
  *  you may not use this file except in compliance with the License.
@@ -40,6 +40,22 @@ public class FileDirectory extends AbstractDirectory {
         mDir = dir;
     }
 
+    @Override
+    public long getSize(String fileName)
+            throws DirectoryException {
+        File file = new File(generatePath(fileName));
+        if (! file.isFile()) {
+            throw new DirectoryException("file must be a file: " + file);
+        }
+        return file.length();
+    }
+
+    @Override
+    public long getCompressedSize(String fileName)
+            throws DirectoryException {
+        return getSize(fileName);
+    }
+
     @Override
     protected AbstractDirectory createDirLocal(String name) throws DirectoryException {
         File dir = new File(generatePath(name));
