@@ -1,6 +1,6 @@
-/**
- *  Copyright (C) 2017 Ryszard Wiśniewski <brut.alll@gmail.com>
- *  Copyright (C) 2017 Connor Tumbleson <connor.tumbleson@gmail.com>
+/*
+ *  Copyright (C) 2010 Ryszard Wiśniewski <brut.alll@gmail.com>
+ *  Copyright (C) 2010 Connor Tumbleson <connor.tumbleson@gmail.com>
  *
  *  Licensed under the Apache License, Version 2.0 (the "License");
  *  you may not use this file except in compliance with the License.
@@ -100,14 +100,34 @@ public class ZipRODirectory extends AbstractDirectory {
         throw new UnsupportedOperationException();
     }
 
+    @Override
+    public long getSize(String fileName)
+            throws DirectoryException {
+        ZipEntry entry = getZipFileEntry(fileName);
+        return entry.getSize();
+    }
+
+    @Override
+    public long getCompressedSize(String fileName)
+            throws DirectoryException {
+        ZipEntry entry = getZipFileEntry(fileName);
+        return entry.getCompressedSize();
+    }
+
     @Override
     public int getCompressionLevel(String fileName)
             throws DirectoryException {
-        ZipEntry entry =  mZipFile.getEntry(fileName);
+        ZipEntry entry = getZipFileEntry(fileName);
+        return entry.getMethod();
+    }
+
+    private ZipEntry getZipFileEntry(String fileName)
+            throws DirectoryException {
+        ZipEntry entry = mZipFile.getEntry(fileName);
         if (entry == null) {
             throw new PathNotExist("Entry not found: " + fileName);
         }
-        return entry.getMethod();
+        return entry;
     }
 
     private void loadAll() {
@@ -120,7 +140,7 @@ public class ZipRODirectory extends AbstractDirectory {
             ZipEntry entry = entries.nextElement();
             String name = entry.getName();
             
-            if (name.equals(getPath()) || ! name.startsWith(getPath())) {
+            if (name.equals(getPath()) || ! name.startsWith(getPath()) || name.contains(".." + separator)) {
                 continue;
             }
             
@@ -136,8 +156,7 @@ public class ZipRODirectory extends AbstractDirectory {
                 subname = subname.substring(0, pos);
             }
             
-            boolean pointsToParentDirectory = (subname.equals("..") && prefixLen == 0);
-            if (! mDirs.containsKey(subname) && ! pointsToParentDirectory) {
+            if (! mDirs.containsKey(subname)) {
                 AbstractDirectory dir = new ZipRODirectory(getZipFile(), getPath() + subname + separator);
                 mDirs.put(subname, dir);                
             }
